==============================
Models Foregrounds
==============================

Zodiacal foreground
--------------------

.. autoclass:: exorad.models.foregrounds.zodiacalForeground.ZodiacalFrg
    :members:
    :undoc-members:
    :show-inheritance:

Sky foreground
--------------------

.. autoclass:: exorad.models.foregrounds.skyForegrounds.SkyForeground
    :members:
    :undoc-members:
    :show-inheritance:

Sky filter
--------------------

.. autoclass:: exorad.models.foregrounds.skyForegrounds.SkyFilter
    :members:
    :undoc-members:
    :show-inheritance:

